@@ -3,13 +3,10 @@
 import json
 import netaddr
 import os
-import os_client_config
+import openstack
 import subprocess
 
 CTLPLANE_NETWORK_NAME = 'ctlplane'
-
-AUTH_URL = os.environ['auth_url']
-ADMIN_PASSWORD = os.environ['admin_password']
 CONF = json.loads(os.environ['config'])
 
 
@@ -66,7 +63,7 @@ def _ensure_neutron_network(sdk):
 
 
 def _neutron_subnet_create(sdk, network_id, cidr, gateway, host_routes,
-                           allocation_pool, name, segment_id, dns_nameservers):
+                           allocation_pools, name, segment_id, dns_nameservers):
     try:
         if netaddr.IPNetwork(cidr).version == 6:
             subnet = sdk.network.create_subnet(
@@ -77,7 +74,7 @@ def _neutron_subnet_create(sdk, network_id, cidr, gateway, host_routes,
                 ip_version='6',
                 ipv6_address_mode='dhcpv6-stateless',
                 ipv6_ra_mode='dhcpv6-stateless',
-                allocation_pools=allocation_pool,
+                allocation_pools=allocation_pools,
                 network_id=network_id,
                 segment_id=segment_id,
                 dns_nameservers=dns_nameservers)
@@ -89,7 +86,7 @@ def _neutron_subnet_create(sdk, network_id, cidr, gateway, host_routes,
                 host_routes=host_routes,
                 enable_dhcp=True,
                 ip_version='4',
-                allocation_pools=allocation_pool,
+                allocation_pools=allocation_pools,
                 network_id=network_id,
                 segment_id=segment_id,
                 dns_nameservers=dns_nameservers)
@@ -102,14 +99,14 @@ def _neutron_subnet_create(sdk, network_id, cidr, gateway, host_routes,
 
 
 def _neutron_subnet_update(sdk, subnet_id, cidr, gateway, host_routes,
-                           allocation_pool, name, dns_nameservers):
+                           allocation_pools, name, dns_nameservers):
     try:
         if netaddr.IPNetwork(cidr).version == 6:
             subnet = sdk.network.update_subnet(
                 subnet_id,
                 name=name,
                 gateway_ip=gateway,
-                allocation_pools=allocation_pool,
+                allocation_pools=allocation_pools,
                 dns_nameservers=dns_nameservers)
         else:
             subnet = sdk.network.update_subnet(
@@ -117,7 +114,7 @@ def _neutron_subnet_update(sdk, subnet_id, cidr, gateway, host_routes,
                 name=name,
                 gateway_ip=gateway,
                 host_routes=host_routes,
-                allocation_pools=allocation_pool,
+                allocation_pools=allocation_pools,
                 dns_nameservers=dns_nameservers)
         print('INFO: Subnet updated %s' % subnet)
     except Exception:
@@ -188,7 +185,17 @@ def _get_segment(sdk, phy, network_id):
     return False if not segment else segment[0]
 
 
-def _local_neutron_segments_and_subnets(sdk, ctlplane_id):
+def _set_network_tags(sdk, network, tags):
+    try:
+        sdk.network.set_tags(network, tags=tags)
+        print('INFO: Tags %s added to network %s.' % (tags, network.name))
+    except Exception:
+        print('ERROR: Setting tags %s on network %s failed.' %
+              (tags, network.name))
+        raise
+
+
+def _local_neutron_segments_and_subnets(sdk, ctlplane_id, net_cidrs):
     """Create's and updates the ctlplane subnet on the segment that is local to
     the underclud.
     """
@@ -198,8 +205,6 @@ def _local_neutron_segments_and_subnets(sdk, ctlplane_id):
     segment = _get_segment(sdk, CONF['physical_network'], ctlplane_id)
     host_routes = [{'destination': '169.254.169.254/32',
                     'nexthop': CONF['local_ip']}]
-    allocation_pool = [{'start': s['DhcpRangeStart'],
-                        'end': s['DhcpRangeEnd']}]
     if subnet:
         if CONF['enable_routed_networks'] and subnet.segment_id == None:
             # The subnet exists and does not have a segment association. Since
@@ -210,7 +215,7 @@ def _local_neutron_segments_and_subnets(sdk, ctlplane_id):
             _neutron_add_subnet_segment_association(sdk, subnet.id, segment.id)
         _neutron_subnet_update(
             sdk, subnet.id, s['NetworkCidr'], s['NetworkGateway'], host_routes,
-            allocation_pool, name, CONF['nameservers'])
+            s.get('AllocationPools'), name, CONF['nameservers'])
     else:
         if CONF['enable_routed_networks']:
             segment_id = segment.id
@@ -218,15 +223,17 @@ def _local_neutron_segments_and_subnets(sdk, ctlplane_id):
             segment_id = None
         subnet = _neutron_subnet_create(
             sdk, ctlplane_id, s['NetworkCidr'], s['NetworkGateway'],
-            host_routes, allocation_pool, name, segment_id,
+            host_routes, s.get('AllocationPools'), name, segment_id,
             CONF['nameservers'])
         # If the subnet is IPv6 we need to start a router so that router
         #  advertisments are sent out for stateless IP addressing to work.
         if netaddr.IPNetwork(s['NetworkCidr']).version == 6:
             _ensure_neutron_router(sdk, name, subnet.id)
+    net_cidrs.append(s['NetworkCidr'])
 
+    return net_cidrs
 
-def _remote_neutron_segments_and_subnets(sdk, ctlplane_id):
+def _remote_neutron_segments_and_subnets(sdk, ctlplane_id, net_cidrs):
     """Create's and updates the ctlplane subnet(s) on segments that is
     not local to the undercloud.
     """
@@ -238,16 +245,14 @@ def _remote_neutron_segments_and_subnets(sdk, ctlplane_id):
         metadata_nexthop = s['NetworkGateway']
         host_routes = [{'destination': '169.254.169.254/32',
                         'nexthop': metadata_nexthop}]
-        allocation_pool = [{'start': s['DhcpRangeStart'],
-                            'end': s['DhcpRangeEnd']}]
-
         subnet = _get_subnet(sdk, s['NetworkCidr'], ctlplane_id)
         segment = _get_segment(sdk, phynet, ctlplane_id)
         if subnet:
             _neutron_segment_update(sdk, subnet.segment_id, name)
             _neutron_subnet_update(
                 sdk, subnet.id, s['NetworkCidr'], s['NetworkGateway'],
-                host_routes, allocation_pool, name, CONF['nameservers'])
+                host_routes, s.get('AllocationPools'), name,
+                CONF['nameservers'])
         else:
             if segment:
                 _neutron_segment_update(sdk, segment.id, name)
@@ -256,30 +261,32 @@ def _remote_neutron_segments_and_subnets(sdk, ctlplane_id):
                                                   phynet)
             subnet = _neutron_subnet_create(
                 sdk, ctlplane_id, s['NetworkCidr'], s['NetworkGateway'],
-                host_routes, allocation_pool, name, segment.id,
+                host_routes, s.get('AllocationPools'), name, segment.id,
                 CONF['nameservers'])
             # If the subnet is IPv6 we need to start a router so that router
             # advertisments are sent out for stateless IP addressing to work.
             if netaddr.IPNetwork(s['NetworkCidr']).version == 6:
                 _ensure_neutron_router(sdk, name, subnet.id)
+        net_cidrs.append(s['NetworkCidr'])
 
+    return net_cidrs
 
 if 'true' not in _run_command(['hiera', 'neutron_api_enabled'],
                               name='hiera').lower():
     print('WARNING: UndercloudCtlplaneNetworkDeployment : The Neutron API '
           'is disabled. The ctlplane network cannot be configured.')
 else:
-    sdk = os_client_config.make_sdk(auth_url=AUTH_URL,
-                                    project_name='admin',
-                                    username='admin',
-                                    password=ADMIN_PASSWORD,
-                                    project_domain_name='Default',
-                                    user_domain_name='Default')
+    sdk = openstack.connect(CONF['cloud_name'])
 
     network = _ensure_neutron_network(sdk)
+    net_cidrs = []
     # Always create/update the local_subnet first to ensure it is can have the
     # subnet associated with a segment prior to creating the remote subnets if
     # the user enabled routed networks support on undercloud update.
-    _local_neutron_segments_and_subnets(sdk, network.id)
+    net_cidrs = _local_neutron_segments_and_subnets(sdk, network.id, net_cidrs)
     if CONF['enable_routed_networks']:
-        _remote_neutron_segments_and_subnets(sdk, network.id)
+        net_cidrs = _remote_neutron_segments_and_subnets(sdk, network.id,
+                                                         net_cidrs)
+    # Set the cidrs for all ctlplane subnets as tags on the ctlplane network.
+    # These tags are used for the NetCidrMapValue in tripleo-heat-templates.
+    _set_network_tags(sdk, network, net_cidrs)
