@@ -35,7 +35,7 @@ PARAMS = (PARAM_CLOUD_ENDPOINTS, PARAM_ENDPOINTMAP, PARAM_NETIPMAP,
           'CloudEndpoints', 'EndpointMap', 'NetIpMap', 'ServiceNetMap')
 FIELDS = (F_PORT, F_PROTOCOL, F_HOST) = ('port', 'protocol', 'host')
 
-ENDPOINT_TYPES = frozenset(['Internal', 'Public', 'Admin'])
+ENDPOINT_TYPES = frozenset(['Internal', 'Public', 'Admin', 'UIConfig'])
 
 
 def get_file(default_fn, override=None, writable=False):
@@ -65,7 +65,8 @@ def net_param_name(endpoint_type_defn):
 def endpoint_map_default(config):
     def map_item(ep_name, ep_type, svc):
         values = collections.OrderedDict([
-            (F_PROTOCOL, svc.get(F_PROTOCOL, 'http')),
+            (F_PROTOCOL, str(svc[ep_type].get(F_PROTOCOL,
+                                              svc.get(F_PROTOCOL, 'http')))),
             (F_PORT, str(svc[ep_type].get(F_PORT, svc[F_PORT]))),
             (F_HOST, SUBST_IP_ADDRESS),
         ])
@@ -150,9 +151,19 @@ def template_output_definition(endpoint_name,
             })
         ])
     }
-    uri_fields = [protocol, '://', copy.deepcopy(host), ':', port]
-    uri_fields_suffix = (copy.deepcopy(uri_fields) +
-                         ([uri_suffix] if uri_suffix is not None else []))
+    uri_no_path = {
+        'make_url': collections.OrderedDict([
+            ('scheme', protocol),
+            ('host', copy.deepcopy(host)),
+            ('port', port)
+        ])
+    }
+    uri_with_path = copy.deepcopy(uri_no_path)
+    if uri_suffix is not None:
+        path, pc, suffix = uri_suffix.partition('%')
+        uri_with_path['make_url']['path'] = path
+        if pc:
+            uri_with_path = {'list_join': ['', [uri_with_path, pc + suffix]]}
 
     name = name_override if name_override is not None else (endpoint_name +
                                                             endpoint_variant +
@@ -163,12 +174,8 @@ def template_output_definition(endpoint_name,
         'host': host,
         'port': extract_field('port'),
         'protocol': extract_field('protocol'),
-        'uri': {
-            'list_join': ['', uri_fields_suffix]
-        },
-        'uri_no_suffix': {
-            'list_join': ['', uri_fields]
-        },
+        'uri': uri_with_path,
+        'uri_no_suffix': uri_no_path,
     }
 
 
@@ -191,7 +198,7 @@ def template_endpoint_items(config):
 
 def generate_endpoint_map_template(config):
     return collections.OrderedDict([
-        ('heat_template_version', 'pike'),
+        ('heat_template_version', 'rocky'),
         ('description', 'A map of OpenStack endpoints. Since the endpoints '
          'are URLs, we need to have brackets around IPv6 IP addresses. The '
          'inputs to these parameters come from net_ip_uri_map, which will '
