@@ -130,7 +130,6 @@ PARAMETER_DEFINITION_EXCLUSIONS = {'CephPools': ['description',
                                    'KeystoneAdminErrorLoggingSource': ['default'],
                                    'KeystoneMainAcccessLoggingSource': ['default'],
                                    'KeystoneMainErrorLoggingSource': ['default'],
-                                   'MongoDbLoggingSource': ['default'],
                                    'NeutronApiLoggingSource': ['default'],
                                    'NeutronDhcpAgentLoggingSource': ['default'],
                                    'NeutronL3AgentLoggingSource': ['default'],
@@ -229,8 +228,6 @@ PREFERRED_CAMEL_CASE = {
 # If a filename is not found in the overrides then the top level directory is
 # used to determine which validation method to use.
 VALIDATE_PUPPET_OVERRIDE = {
-  # docker/service/sshd.yaml is a variation of the puppet sshd service
-  './docker/services/sshd.yaml': True,
   # docker/services/messaging/*.yaml provide oslo_messaging services
   './docker/services/messaging/notify-rabbitmq-shared.yaml': False,
   './docker/services/messaging/notify-rabbitmq.yaml': False,
@@ -249,8 +246,6 @@ VALIDATE_PUPPET_OVERRIDE = {
 
 }
 VALIDATE_DOCKER_OVERRIDE = {
-  # docker/service/sshd.yaml is a variation of the puppet sshd service
-  './docker/services/sshd.yaml': False,
   # docker/services/messaging/notify-rabbitmq-shared.yaml does not
   # deploy container
   './docker/services/messaging/notify-rabbitmq-shared.yaml': False,
@@ -478,7 +473,7 @@ def validate_multiarch_compute_roles(role_filename, role_tpl):
     errors = 0
     roles_dir = os.path.dirname(role_filename)
     compute_services = set(role_tpl[0].get('ServicesDefault', []))
-    compute_networks = set(role_tpl[0].get('networks', []))
+    compute_networks = role_tpl[0].get('networks', [])
 
     for arch in ['ppc64le']:
         arch_filename = os.path.join(roles_dir,
@@ -493,7 +488,7 @@ def validate_multiarch_compute_roles(role_filename, role_tpl):
             print('ERROR problems with: %s' % (','.join(compute_services.symmetric_difference(arch_services))))
             errors = 1
 
-        arch_networks = set(arch_tpl[0].get('networks', []))
+        arch_networks = arch_tpl[0].get('networks', [])
         if compute_networks != arch_networks:
             print('ERROR networks in %s and %s do not match' %
                   (role_filename, arch_filename))
@@ -748,10 +743,13 @@ def validate_service(filename, tpl):
             print('ERROR: service_name is required in role_data for %s.'
                   % filename)
             return 1
-        # service_name must match the filename, but with an underscore
-        if (role_data['service_name'] !=
-                os.path.basename(filename).split('.')[0].replace("-", "_")):
-            print('ERROR: service_name should match file name for service: %s.'
+        # service_name must match the beginning of the file name, but with an
+        # underscore
+        service_name = \
+                os.path.basename(filename).split('.')[0].replace("-", "_")
+        if not role_data['service_name'].startswith(service_name):
+            print('ERROR: service_name should match the beginning of the '
+                  'filename: %s.'
                   % filename)
             return 1
         # if service connects to mysql, the uri should use option
@@ -1063,7 +1061,8 @@ def validate(filename, param_map):
                 VALIDATE_PUPPET_OVERRIDE.get(filename, True)):
             retval |= validate_service(filename, tpl)
 
-        if re.search(r'(puppet|docker)\/services', filename):
+        if re.search(r'(puppet|docker)\/services', filename) or \
+                re.search(r'deployment\/', filename):
             retval |= validate_service_hiera_interpol(filename, tpl)
 
         if filename.startswith('./docker/services/logging/'):
